@@ -2,7 +2,7 @@ use jsonrpsee::proc_macros::rpc;
 use jsonrpsee::types::RpcResult;
 #[rpc(client, server)]
 pub trait DuplicatedAlias {
-	#[method(name = "foo", aliases = "foo_dup, foo_dup")]
+	#[method(name = "foo", aliases = ["foo_dup", "foo_dup"])]
 	async fn async_method(&self) -> RpcResult<u8>;
 }
 
